pub struct Icon {
pub width: u32,
pub height: u32,
pub path: &'static str,
}Expand description
An icon made up of a single path (which should be filled with whatever color we want).
Fields
width: u32The width of the icon.
height: u32The height of the icon.
path: &'static strThe icon’s path, in SVG format.
Implementations
Sourceimpl Icon
impl Icon
pub fn to_custom_widget<T>( &self, brush: impl Into<BackgroundBrush<T>>, ) -> IconWidget<T>
pub fn to_widget(&self) -> IconWidget<bool>